#!/bin/bash

# Define the file
TOC_FILE="CzechQuests.toc"

if [[ -f "$TOC_FILE" ]]; then
    # Read version number from the file
    VERSION=$(grep "## Version:" "$TOC_FILE" | cut -d ' ' -f 3)
    echo "Version: $VERSION"
else
    echo "File $TOC_FILE does not exist."
fi

# Define the name of the zipfile
ZIPFILE="czech-quests-v$VERSION.zip"

# Define the output directory
OUT_DIR="CzechQuests"

# Create the output directory
mkdir -p $OUT_DIR

# Define files/directories to copy
FILES_TO_COPY="*"

# Define files/directories to exclude while copying
# File names should be separated by space and wrapped in double quotes
EXCLUDE_FILES=(
  ".git"
  ".idea"
  ".png"
  ".sh"
  "README.md"
  "czech-quest-v",
  "Data"
  $OUT_DIR
)

# Copy files to the output directory
for FILE in $FILES_TO_COPY
do
  echo "Processing $FILE file..."
  if [[ ! " ${EXCLUDE_FILES[@]} " =~ " ${FILE} " ]]; then
    cp -r $FILE $OUT_DIR
    echo "Copied $FILE"
  fi
done

# Create the zip file at parent level, including the 'dist' directory
zip -r $ZIPFILE $OUT_DIR

# Optionally, remove the copied unzipped files in 'dist'
 rm -rf $OUT_DIR
